==> ksystemlog_16.04.3.orig.tar.xz: ksystemlog-16.04.3/src/modes/base/logLevelSelectionDialog.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _LOG_LEVEL_SELECTION_DIALOG_H_
#define _LOG_LEVEL_SELECTION_DIALOG_H_

#include <QDialog>

#include "ui_logLevelSelectionDialogBase.h"

class LogLevelSelectionDialog : public QDialog, public Ui::LogLevelSelectionDialogBase
{
public:
    explicit LogLevelSelectionDialog(QWidget *parent = NULL);

    virtual ~LogLevelSelectionDialog();

    QListWidget *logLevels() const;
};

#endif //_LOG_LEVEL_SELECTION_DIALOG_H_

==> ksystemlog_20.12.0.orig.tar.xz: ksystemlog-20.12.0/src/modes/base/logLevelSelectionDialog.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef LOG_LEVEL_SELECTION_DIALOG_H
#define LOG_LEVEL_SELECTION_DIALOG_H

#include <QDialog>

#include "ui_logLevelSelectionDialogBase.h"

class LogLevelSelectionDialog : public QDialog, public Ui::LogLevelSelectionDialogBase
{
public:
    explicit LogLevelSelectionDialog(QWidget *parent = nullptr);

    virtual ~LogLevelSelectionDialog();

    QListWidget *logLevels() const;
};

#endif //_LOG_LEVEL_SELECTION_DIALOG_H
